----
-- $Rev: 41 $:     Revision der letzten Änderung
-- $Author: FoxAlpha $:  Author der letzten Änderung
-- $Date: 2012-12-22 00:46:35 +0100 (Sa, 22. Dez 2012) $:    Date der letzten Änderung
----

----
--	Funktion um eine standard Konfigurationsdatei anzulegen
--	Function to create default config file
----
function ClockMod:createClockModConfig()

	local configFile;
	local PathToModDir;
	local cmXml;
	local xmlSaved;
	
	configFile = self:getModName(self.moddir) .. "Config.xml";
	PathToModDir = string.gsub(self.moddir, self.modName.."/", "");
	
	cmXml = createXMLFile("ClockModXML", PathToModDir .. "ClockModConfig.xml", "ClockMod");
	
	if cmXml ~= nil then
		setXMLString(cmXml, "clockmod.version", "v1.1");
		setXMLString(cmXml, "clockmod.copyright", g_i18n:getText("clockmodtxt"));
		
		xmlSaved = self:saveConfigToXML(cmXml);

		if xmlSaved then
			print(g_i18n:getText("clockmodtxt") .. " : " .. g_i18n:getText("CM_CreateConfigFileSuccess"));
		else
			print(g_i18n:getText("clockmodtxt") .. " : " .. g_i18n:getText("CM_ErrorCreateConfigFile"));
		end; 
		saveXMLFile(cmXml);
	else
		print(g_i18n:getText("clockmodtxt") .. " : " .. g_i18n:getText("CM_ErrorCreateConfigFile"));
	end;
end;
----

----
--	Funktion um die Einstellungen aus der Konfigurationsdatei zu laden
--	Function to load options from configfile
----
function ClockMod:loadClockModConfig()
	local configFile;
	local PathToModDir;
	local cmXml;
	
	configFile = self:getModName(self.moddir) .. "Config.xml";
	PathToModDir = string.gsub(self.moddir, self.modName.."/", "");
	
	if fileExists(PathToModDir .. "ClockModConfig.xml") then
		cmXml = loadXMLFile("ClockModXML", PathToModDir .. "ClockModConfig.xml", "ClockMod");
	else
		return false;
	end;
	
	if cmXml ~= nil then
	
		self.cmEnabled = getXMLBool(cmXml, "clockmod.enable");
		self.cmVersion = getXMLString(cmXml, "clockmod.version");
		
		if not self.cmEnabled then
			print(g_i18n:getText("clockmodtxt") .. " : " .. g_i18n:getText("CM_ClockModIsDisabeld"));
			return false;
		end;

		for k,v in pairs(self.txtColors.date) do
			self.txtColors.date[k] = getXMLFloat(cmXml, "clockmod.Texts.date.color#".. k);
		end;
		self.cmPanel.fontsize.date = getXMLFloat(cmXml, "clockmod.Texts.date#fontSize");
		self.cmPanel.indent.date = getXMLFloat(cmXml, "clockmod.Texts.date#indent");
		
		for k,v in pairs(self.txtColors.time) do
			self.txtColors.time[k] = getXMLFloat(cmXml, "clockmod.Texts.time.color#".. k);
		end;
		self.cmPanel.fontsize.time = getXMLFloat(cmXml, "clockmod.Texts.time#fontSize");
		self.cmPanel.indent.time = getXMLFloat(cmXml, "clockmod.Texts.time#indent");
		
		for k,v in pairs(self.txtColors.data) do
			self.txtColors.data[k] = getXMLFloat(cmXml, "clockmod.Texts.data.color#".. k);
		end;
		self.cmPanel.fontsize.data = getXMLFloat(cmXml, "clockmod.Texts.data#fontSize");
		self.cmPanel.indent.data = getXMLFloat(cmXml, "clockmod.Texts.data#indent");
		
		for k,v in pairs(self.txtColors.title) do
			self.txtColors.title[k] = getXMLFloat(cmXml, "clockmod.Texts.title.color#".. k);
		end;
		self.cmPanel.fontsize.title = getXMLFloat(cmXml, "clockmod.Texts.title#fontSize");
		self.cmPanel.indent.title = getXMLFloat(cmXml, "clockmod.Texts.title#indent");
		
		----
		--	Panel
		----
		self.cmPanel.usePanel = getXMLBool(cmXml, "clockmod.panel#usePanel");
		self.cmPanel.position.x = getXMLFloat(cmXml, "clockmod.panel.position#x");
		self.cmPanel.position.y = getXMLFloat(cmXml, "clockmod.panel.position#y");
		self.cmPanel.position.w = getXMLFloat(cmXml, "clockmod.panel.position#w"); --256px
		self.cmPanel.files.fileTop.file = getXMLString(cmXml, "clockmod.panel.fileTop");
		self.cmPanel.files.fileBot.height = getXMLFloat(cmXml, "clockmod.panel.fileTop#height");	-- 16px
		self.cmPanel.files.fileMid.file = getXMLString(cmXml, "clockmod.panel.fileMid");
		self.cmPanel.files.fileBot.height = getXMLFloat(cmXml, "clockmod.panel.fileMid#height");	-- 32px
		self.cmPanel.files.fileBot.file = getXMLString(cmXml, "clockmod.panel.fileBot");
		self.cmPanel.files.fileBot.height = getXMLFloat(cmXml, "clockmod.panel.fileBot#height"); -- 16px
		----		
		saveXMLFile(cmXml);
		
		print(g_i18n:getText("clockmodtxt") .. " : " .. g_i18n:getText("CM_LoadConfigFileSuccess"));
		return true;
   else
        print(g_i18n:getText("clockmodtxt") .. " : " .. g_i18n:getText("CM_ErrorLoadConfig"));
		return false;
   end;  	
  
end;
----

----
--	Funktionen um die Einstellungen in der Konfigurationsdatei zu speichern
--	Function to load options from configfile
----
function ClockMod:saveClockModConfig()
	local configFile;
	local PathToModDir;
	local cmXml;
	
	configFile = self:getModName(self.moddir) .. "Config.xml";
	PathToModDir = string.gsub(self.moddir, self.modName.."/", "");
	
	cmXml = loadXMLFile("ClockModXML", PathToModDir .. "ClockModConfig.xml", "ClockMod");
	
	if self:saveConfigToXML(cmXml) then
		print(g_i18n:getText("clockmodtxt") .. " : " .. g_i18n:getText("CM_SaveConfigFileSuccess"));
		saveXMLFile(cmXml);
	else
        print(g_i18n:getText("clockmodtxt") .. " : " .. g_i18n:getText("CM_ErrorSaveConfig"));
	end;    

end;
----
function ClockMod:saveConfigToXML(cmXml)

	if cmXml ~= nil then	
	
		setXMLBool(cmXml, "clockmod.enable", self.cmEnabled);
		
		----
		--	Farben definieren
		----		
		setXMLString(cmXml, "clockmod.Texts.date", "Color for datestring");
		for k,v in pairs(self.txtColors.date) do
			setXMLFloat(cmXml, "clockmod.Texts.date.color#".. k, v);
		end;
		setXMLFloat(cmXml, "clockmod.Texts.date#fontSize", self.cmPanel.fontsize.date);
		setXMLFloat(cmXml, "clockmod.Texts.date#indent", self.cmPanel.indent.date);

		setXMLString(cmXml, "clockmod.Texts.time", "color for time string");
		for k,v in pairs(self.txtColors.time) do
			setXMLFloat(cmXml, "clockmod.Texts.time.color#".. k, v);
		end;
		setXMLFloat(cmXml, "clockmod.Texts.time#fontSize", self.cmPanel.fontsize.time);
		setXMLFloat(cmXml, "clockmod.Texts.time#indent", self.cmPanel.indent.time);

		setXMLString(cmXml, "clockmod.Texts.title", "color for playtime data title");
		for k,v in pairs(self.txtColors.title) do
			setXMLFloat(cmXml, "clockmod.Texts.title.color#".. k, v);
		end;
		setXMLFloat(cmXml, "clockmod.Texts.title#fontSize", self.cmPanel.fontsize.title);
		setXMLFloat(cmXml, "clockmod.Texts.title#indent", self.cmPanel.indent.title);

		setXMLString(cmXml, "clockmod.Texts.data", "color for playtime data");
		for k,v in pairs(self.txtColors.data) do
			setXMLFloat(cmXml, "clockmod.Texts.data.color#".. k, v);
		end;
		setXMLFloat(cmXml, "clockmod.Texts.data#fontSize", self.cmPanel.fontsize.data);
		setXMLFloat(cmXml, "clockmod.Texts.data#indent", self.cmPanel.indent.data);
		----
		
		----
		--	Panel
		----
		setXMLString(cmXml, "clockmod.panel", "Position for the panel data and Background. Not ready");
		setXMLBool(cmXml, "clockmod.panel#usePanel", self.cmPanel.usePanel);
		setXMLFloat(cmXml, "clockmod.panel.position#x", self.cmPanel.position.x);
		setXMLFloat(cmXml, "clockmod.panel.position#y", self.cmPanel.position.y);
		setXMLFloat(cmXml, "clockmod.panel.position#w", self.cmPanel.position.w); --256px
		setXMLString(cmXml, "clockmod.panel.fileTop", self.cmPanel.files.fileTop.file);
		setXMLFloat(cmXml, "clockmod.panel.fileTop#height", self.cmPanel.files.fileTop.height);	-- 16px
		setXMLString(cmXml, "clockmod.panel.fileMid", self.cmPanel.files.fileMid.file);
		setXMLFloat(cmXml, "clockmod.panel.fileMid#height", self.cmPanel.files.fileMid.height);	-- 32px
		setXMLString(cmXml, "clockmod.panel.fileBot", self.cmPanel.files.fileBot.file);
		setXMLFloat(cmXml, "clockmod.panel.fileBot#height", self.cmPanel.files.fileBot.height); -- 16px
		----
		
		return true;
	else
		return false;
	end;
end;
----

----
-- Namen der Datei eines Mods ermitteln
-- Ermittelt aus dem Pfad den Namen ohne Dateiendung
----
function ClockMod:getModName(s) 
	local temp;
	local PathToModDir;
	
	PathToModDir = string.gsub(self.moddir, self.modName.."/", "");

	s = string.gsub(s, PathToModDir, "");
	s = string.gsub(s, "/", "");
	temp = s;
	
	return temp;
end;
----

